@@ -2,27 +2,36 @@ from __future__ import division
 
 import math
 import re
+import json
 from collections import OrderedDict
 
+import django
+from django.db.models.query import QuerySet
 from django.forms.forms import BoundField
 from django.template import Library
 from django.template.base import (
     Node, TemplateSyntaxError, Variable, token_kwargs
 )
+from django.core.serializers.json import DjangoJSONEncoder
 from django.utils import formats
-from django.utils.encoding import force_text
+
+from django.utils.html import escape
 
 from ..base import Field
 from ..widgets import SelectDateWidget
 from .material_form import FormPartNode, WidgetAttrNode, _render_parts
 
+if django.VERSION < (3,):
+    from django.utils.encoding import force_text
+else:
+    from django.utils.encoding import force_str as force_text
 
 register = Library()
 
 
 @register.tag('render')
 class FormRenderNode(Node):
-    """Shugar for element in template rendering."""
+    """Sugar for element in template rendering."""
 
     def __init__(self, parser, token):  # noqa D102
         bits = token.split_contents()
@@ -133,13 +142,13 @@ def jquery_datepicker_format(field):
 
 @register.filter
 def datepicker_value(value, date_format):
-    """Retun localized date value."""
+    """Return localized date value."""
     return formats.localize_input(value, date_format)
 
 
 @register.filter('force_text')
 def force_text_impl(value):
-    """Coerse widget value to text."""
+    """Coerce widget value to text."""
     return force_text(value)
 
 
@@ -148,7 +157,7 @@ def split_choices_by_columns(choices, columns):
     """Split CheckboxSelectMultiple values into columns."""
     columns = int(columns)
     col_span = 12 // columns
-    per_column = int(math.ceil(len(choices)/columns))
+    per_column = int(math.ceil(len(choices) / columns))
     choices = [tuple(choice) + (i,) for i, choice in enumerate(choices)]
     return [
         (col_span, choices[i:i + per_column])
@@ -181,12 +190,12 @@ def is_initial_file(value):
 @register.filter
 def is_null_boolean_selected(bound_field, value):
     """Return NullBooleanField state."""
-    BOOL_VALUES = {True: '2', False: '3', '2': '2', '3': '3'}
+    BOOL_VALUES = {True: True, False: False, 'true': True, 'false': False, '2': True, '3': False}
     try:
-        current_value = BOOL_VALUES[bound_field.value()]
+        current_value = BOOL_VALUES[value]
     except KeyError:
-        current_value = '1'
-    return value == current_value
+        current_value = None
+    return bound_field.value() == current_value
 
 
 @register.filter
@@ -197,7 +206,7 @@ def select_options(bound_field):
     If group_name is None - option is not belongs to group
     """
     selected = bound_field.value()
-    if not isinstance(selected, (list, tuple)):
+    if not isinstance(selected, (list, tuple, QuerySet)):
         selected = [selected]
     selected = set(force_text(v) for v in selected)
 
@@ -223,3 +232,15 @@ def select_options(bound_field):
             )
 
     return groups.items()
+
+
+class JSONEncoder(DjangoJSONEncoder):
+    def default(self, obj):
+        if obj.__class__.__module__ == 'django.utils.functional':
+            return force_text(obj)
+        return json.JSONEncoder.default(self, obj)
+
+
+@register.filter
+def to_json_attr(obj):
+    return escape(json.dumps(obj, cls=JSONEncoder))
